@@ -1,6 +1,6 @@
 package Map::Tube;
 
-$Map::Tube::VERSION   = '3.81';
+$Map::Tube::VERSION   = '3.82';
 $Map::Tube::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Map::Tube - Lightweight Routing Framework.
 
 =head1 VERSION
 
-Version 3.81
+Version 3.82
 
 =cut
 
@@ -830,7 +830,7 @@ sub _get_all_routes {
 sub _map_node_name {
     my ($self, $name, $id) = @_;
 
-    push @{$self->{name_to_id}->{uc($name)}}, $id;
+    $self->{name_to_id}->{uc($name)} = $id;
 }
 
 sub _validate_input {
@@ -891,7 +891,6 @@ sub _init_map {
         $master_line_data->{$_->{id}} = 1;
     }
 
-    my $name_to_id = $self->{name_to_id};
     my $has_station_index = {};
     foreach my $station (@{$data->{stations}->{station}}) {
         my $id = $station->{id};
@@ -909,7 +908,7 @@ sub _init_map {
             method      => $method,
             message     => "ERROR: Duplicate Station Name [$name].",
             filename    => $caller[1],
-            line_number => $caller[2] }) if (defined $name_to_id->{uc($name)});
+            line_number => $caller[2] }) if (defined $self->{name_to_id}->{uc($name)});
 
         $self->_map_node_name($name, $id);
         $tables->{$id} = Map::Tube::Table->new({ id => $id });
@@ -1310,15 +1309,7 @@ sub _get_table {
 sub _get_node_id {
     my ($self, $name) = @_;
 
-    my $nodes = $self->{name_to_id}->{uc($name)};
-    return unless defined $nodes;
-
-    if (wantarray) {
-        return @{$nodes};
-    }
-    else {
-        return $nodes->[0];
-    }
+    return $self->{name_to_id}->{uc($name)};
 }
 
 sub _get_line_object_by_name {
